pub struct AssetCtx {
pub funding: String,
pub open_interest: String,
pub prev_day_px: String,
pub day_ntl_vlm: String,
pub premium: Option<String>,
pub oracle_px: String,
pub mark_px: String,
pub mid_px: Option<String>,
pub impact_pxs: Option<Vec<String>>,
}Expand description
Asset context containing pricing information.
This is the main structure containing oracle prices.
Fields
funding: StringFunding rate (as string, needs parsing)
open_interest: StringOpen interest (as string, needs parsing)
prev_day_px: StringPrevious day’s price
day_ntl_vlm: StringDay’s notional volume
Premium (mark - oracle)
oracle_px: StringOracle/index price - THIS IS WHAT WE WANT This is the spot price from external exchanges, not influenced by HL funding
mark_px: StringMark price (oracle + premium adjustment)
mid_px: Option<String>Mid price from orderbook
impact_pxs: Option<Vec<String>>Impact prices for slippage calculation
Implementations
Sourceimpl AssetCtx
impl AssetCtx
Sourcepub fn oracle_price(&self) -> Option<f64>
pub fn oracle_price(&self) -> Option<f64>
Parse oracle price as f64.
Returns None if the price string cannot be parsed.
Sourcepub fn prev_day_price(&self) -> Option<f64>
pub fn prev_day_price(&self) -> Option<f64>
Parse previous day’s price as f64.
Sourcepub fn mark_price(&self) -> Option<f64>
pub fn mark_price(&self) -> Option<f64>
Parse mark price as f64.
Returns None if the price string cannot be parsed.
Sourcepub fn funding_rate(&self) -> Option<f64>
pub fn funding_rate(&self) -> Option<f64>
Parse funding rate as f64.
Sourcepub fn open_interest_value(&self) -> Option<f64>
pub fn open_interest_value(&self) -> Option<f64>
Parse open interest as f64.